#ifndef __MULTI_CONFIG_H_
#define __MULTI_CONFIG_H_

#include <config.h>
#include_next <linux/config.h>

#endif

